@@ -26,6 +26,11 @@
 
 ;;; Code:
 
+(defvar rail-additional-flim-codename-alist nil
+  "Additional codename for FLIM")
+(defvar rail-additional-semi-codename-alist nil
+  "Additional codename for SEMI")
+
 (defun rail-replace-character (string src dst)
   "Replace character src -> dst"
   (let ((len (length string))
@@ -84,8 +89,11 @@
            (rail-replace-character rail-en-flim-codename ?.AN~ ?.DN~)
            (rail-replace-character rail-en-flim-codename ?.ANr ?.DNr))
       (defvar rail-ja-flim-codename
-	(cdr (assoc rail-en-flim-codename rail-flim-codename-alist))
+	(cdr (assoc rail-en-flim-codename
+                    (append rail-additional-flim-codename-alist rail-flim-codename-alist)))
         "Japanese flim codename.")
+      (and (eq 0 (length rail-ja-flim-codename))
+           (setq rail-ja-flim-codename rail-en-flim-codename))
       (defvar rail-en-semi-codename
 	(mime-product-code-name mime-user-interface-product)
         "ISO-8859-4 semi codename .")
@@ -93,8 +101,11 @@
            (rail-replace-character rail-en-semi-codename ?.AN~ ?.DN~)
            (rail-replace-character rail-en-semi-codename ?.ANr ?.DNr))
       (defvar rail-ja-semi-codename
-	(cdr (assoc rail-en-semi-codename rail-semi-codename-alist))
+	(cdr (assoc rail-en-semi-codename
+                    (append rail-additional-semi-codename-alist rail-semi-codename-alist)))
         "Japanese semi codename.")
+      (and (eq 0 (length rail-ja-semi-codename))
+           (setq rail-ja-semi-codename rail-en-semi-codename))
       (and (boundp 'pgp-version)
            (let ((pgp-document (get 'pgp-version 'variable-documentation)))
 	     (setq pgpgpg-flag
